/*************************************
 * Linux Theme                       *
 * Author: David Rosca               *
 * Using native widgets and icons    *
 *************************************/

*[html-link-look="true"]
{
    color: palette(link);
    text-decoration: underline;
}

/*MainWindow*/
#statusbar-ip-label
{
    padding-right: 5px;
}

/*NavigationBar*/
#navigation-button-back
{
    qproperty-themeIcon: "go-previous";
}

#navigation-button-next
{
    qproperty-themeIcon: "go-next";
}

#navigation-button-stop
{
    qproperty-themeIcon: "process-stop";
}

#navigation-button-reload
{
    qproperty-themeIcon: "view-refresh";
}

#navigation-button-home
{
    qproperty-themeIcon: "go-home";
}

#navigation-button-addtab
{
    qproperty-themeIcon: "list-add";
}

#navigation-button-tools
{
    qproperty-themeIcon: "arrow-right-double";
    qproperty-fallbackIcon: url(images/tools.svg);
}

#navigation-button-exitfullscreen
{
    qproperty-themeIcon: "view-restore";
    qproperty-fallbackIcon: url(images/exit-fullscreen.svg);
}

#navigation-button-supermenu
{
    qproperty-themeIcon: "application-menu";
    qproperty-fallbackIcon: url(images/menu.svg);
}

#navigation-toolbutton-badge
{
    background: palette(dark);
    color: palette(bright-text);
    margin: 0px 1px;
}

ToolButton[button-id="button-downloads"]
{
    qproperty-themeIcon: "edit-download";
}

/*TabWidget*/
#tabbar
{
    qproperty-tabPadding: -1;
    qproperty-baseColor: 0;
}

#tabbar-button-right
{
    qproperty-themeIcon: "arrow-right";
    qproperty-fallbackIcon: url(images/tab-right-arrow.svg);
    qproperty-fixedsize: 15px 25px;
}

#tabbar-button-left
{
    qproperty-themeIcon: "arrow-left";
    qproperty-fallbackIcon: url(images/tab-left-arrow.svg);
    qproperty-fixedsize: 15px 25px;
}

#tabwidget-button-opentabs
{
    qproperty-themeIcon: "arrow-down";
    qproperty-fallbackIcon: url(images/arrow-down.svg);
    qproperty-fixedsize: 20px 25px;
}

#tabwidget-button-closedtabs
{
    qproperty-themeIcon: "user-trash-full";
    qproperty-fixedsize: 22px 25px;
}

#tabwidget-button-addtab
{
    qproperty-themeIcon: "list-add";
    qproperty-fixedsize: 22px 25px;
}

/*IconProvider*/
IconProvider
{
    qproperty-bookmarkIcon: url(images/star-a.svg);
}

/*LocationBar*/
#locationbar
{
    qproperty-leftMargin: 25;
}

#locationbar-bookmarkicon
{
    qproperty-themeIcon: "rating-unrated";
    qproperty-fallbackIcon: url(images/star.svg);
    qproperty-fixedsize: 16px 16px;
}

#locationbar-bookmarkicon[bookmarked="true"]
{
    qproperty-themeIcon: "rating";
    qproperty-fallbackIcon: url(images/star-a.svg);
    qproperty-fixedsize: 16px 16px;
}

#locationbar-siteicon
{
    border-image: url(images/transp.png);
    padding-left: 5px;
    qproperty-fixedsize: 25px 16px;
}

#locationbar-goicon
{
    qproperty-themeIcon: "go-jump-locationbar";
    qproperty-fallbackIcon: url(images/goto.svg);
    qproperty-fixedsize: 16px 16px;
}

#locationbar-down-icon
{
    qproperty-themeIcon: "arrow-down";
    qproperty-fallbackIcon: url(images/arrow-down.svg);
    qproperty-fixedsize: 12px 16px;
}

#locationbar-autofillicon
{
    qproperty-themeIcon: "user-identity";
    qproperty-fallbackIcon: url(images/user.svg);
    qproperty-fixedsize: 16px 16px;
}

/*WebSearchBar*/
#websearchbar
{
    qproperty-leftMargin: 25;
}

#websearchbar-searchbutton
{
    qproperty-fixedsize: 22px 16px;
    qproperty-themeIcon: "edit-find";
}

#websearchbar-searchprovider-combobox
{
    border-image: url(images/transp.png);
    padding-left: 5px;
    qproperty-fixedsize: 25px 16px;
}

/*BookmarksToolbar*/
#bookmarksbar QToolButton
{
    border-image: url(images/transp.png);
    border-width: 0px;
    height: 15px;
}

#bookmarksbar, #bookmarksbar BookmarksToolbarButton {
    padding: 0px;
}

/*SideBar*/
#sidebar
{
    background: transparent;
}

/*SearchToolbar*/
SearchToolBar #lineEdit[notfound="true"]
{
    background: #ff6666;
}

/*AboutDialog*/
AboutDialog #label
{
    background: palette(window);
}

AboutDialog #textLabel
{
    background: palette(window);
}

/*DesktopNotification*/
DesktopNotification
{
    background: #31363b;
}

DesktopNotification #frame
{
    border: 1px solid #696d71;
    padding: 10px;
}

DesktopNotification #heading
{
    font: bold;
    color: #c2c7c7;
}

DesktopNotification #text
{
    color: #e7ebeb;
}

/*BrowsingLibrary*/
BrowsingLibrary #tabs
{
    qproperty-bgPixmap: url(images/library-bg.png);
}

BrowsingLibrary #frame
{
    background: url(images/library-bg.png);
}

/*JavaScript Dialogs*/
#jsFrame
{
    background: url(images/semi-transp.png);
}

QFrame[js-frame="true"]
{
    border: 1px solid  black;
    border-bottom: 0px;
    background-color: white;
}

QFrame[js-frame2="true"]
{
    border: 1px solid  black;
    border-top: 0px;
    background-color: #f3f3f3;
}
